flat_sandbox

Function flat_sandbox 

pub fn flat_sandbox() -> &'static Nub<Flat>
A process-wide Nub<Flat> over the KVM sandbox.

There can only ever be one Hyperlight sandbox per process — the guest-VA window is a single process-wide reservation that is never released, even after drop — so every caller shares this one.